==> zircon_1.18.187.orig.tar.gz: zircon-1.18.187.orig/lib/Help.tcl <==
#
# $Source: /home/nlfm/Zircon/lib/RCS/Help.tcl,v $
# $Date: 1998/07/10 13:33:50 $
# $Revision: 1.18.1.10 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
package provide zircon 1.18
#
proc makeHelp {win nm} {
    $win delete 0 end
    global zircon
    if {[catch {set st [glob [file join $zircon(lib) help $nm *]]}]} {
	$win add command -label {Sorry, not yet available.} -command {}
    } {
	$win delete 0 end
	set hc 0
	foreach x $st {
	    set tx [file tail $x]
	    set ntx m[incr hc]
	    if {[file isdir $x]} {
		$win add cascade -label $tx -menu $win.$ntx
		if {![winfo exists $win.$ntx]} {
		    menu $win.$ntx -tearoff 0 \
		      -postcommand "makeHelp $win.$ntx [file join $nm $tx]"
		}
	    } { 
		$win add command -label $tx \
		  -command "zHelpWind .@$nm$tx $x {Zircon Help : $nm > $tx}"
	    }
	}
    }
}
#
proc zHelpWind {ctl file title} {
    if {[winfo exists $ctl]} { popup $ctl ; return }
    makeToplevel $ctl $title {} {}
    set oFrm $ctl
    grid columnconfigure $ctl 0 -weight 1
    grid rowconfigure $ctl 0 -weight 1
    scrollbar $ctl.vs -command "$ctl.txt yview"
    text $ctl.txt -yscrollcommand "$ctl.vs set" -height 10 -width 40
    $ctl.txt tag configure input -foreground red
    $ctl.txt tag configure output -foreground black
    grid $ctl.vs -row 0 -column 1 -sticky ns
    grid $ctl.txt -row 0 -column 0 -sticky nsew
    grid [button $ctl.close -text [trans dismiss] -command "destroy $ctl"] -
    set desc [open $file r]
    while {![eof $desc]} {
	gets $desc buffer
	switch {} $buffer {
	    $ctl.txt insert end "\n\n"
	} default {
	    $ctl.txt insert end "$buffer "
	}
    }
    close $desc
    $ctl.txt configure -state disabled
}

==> zircon_1.18.224.orig.tar.gz: zircon-1.18.224.orig/lib/Help.tcl <==
#
# $Source: /home/nlfm/Zircon/lib/RCS/Help.tcl,v $
# $Date: 1998/12/07 13:14:42 $
# $Revision: 1.18.1.11 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
package provide zircon 1.18
#
proc makeHelp {win nm} {
    $win delete 0 end
    global zircon
    if {[catch {set st [glob [file join $zircon(lib) help $nm *]]}]} {
	$win add command -label {Sorry, not yet available.} -command {}
    } {
	$win delete 0 end
	set hc 0
	foreach x $st {
	    set tx [file tail $x]
	    set ntx m[incr hc]
	    if {[file isdir $x]} {
		$win add cascade -label $tx -menu $win.$ntx
		if {![winfo exists $win.$ntx]} {
		    menu $win.$ntx -tearoff 0 \
		      -postcommand "makeHelp $win.$ntx [list [file join $nm $tx]]"
		}
	    } { 
		$win add command -label $tx \
		  -command "zHelpWind .@$nm$tx [list $x] {Zircon Help : $nm > $tx}"
	    }
	}
    }
}
#
proc zHelpWind {ctl file title} {
    if {[winfo exists $ctl]} { popup $ctl ; return }
    makeToplevel $ctl $title {} {}
    set oFrm $ctl
    grid columnconfigure $ctl 0 -weight 1
    grid rowconfigure $ctl 0 -weight 1
    scrollbar $ctl.vs -command "$ctl.txt yview"
    text $ctl.txt -yscrollcommand "$ctl.vs set" -height 10 -width 40
    $ctl.txt tag configure input -foreground red
    $ctl.txt tag configure output -foreground black
    grid $ctl.vs -row 0 -column 1 -sticky ns
    grid $ctl.txt -row 0 -column 0 -sticky nsew
    grid [button $ctl.close -text [trans dismiss] -command "destroy $ctl"] -
    set desc [open $file r]
    while {![eof $desc]} {
	gets $desc buffer
	switch {} $buffer {
	    $ctl.txt insert end "\n\n"
	} default {
	    $ctl.txt insert end "$buffer "
	}
    }
    close $desc
    $ctl.txt configure -state disabled
}
